typing_extensions: Backported and Experimental Type Hints for Python 3.8+
=========================================================================

Description
-----------

Backported and Experimental Type Hints for Python 3.8+

License
-------

PSF

Upstream Contact
----------------

https://pypi.org/project/typing-extensions/

